==> 0.9.0.tar.gz: lib/src/api/media.dart <==
// Copyright (C) 2019  Wilko Manger
//
// This file is part of matrix-dart-sdk.
//
// matrix-dart-sdk is free software: you can redistribute it and/or modify
// it under the terms of the GNU Affero General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// matrix-dart-sdk is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Affero General Public License for more details.
//
// You should have received a copy of the GNU Affero General Public License
// along with matrix-dart-sdk.  If not, see <https://www.gnu.org/licenses/>.
import "dart:async";
import 'package:chopper/chopper.dart';
import 'package:matrix_sdk/src/api/api.dart';
import 'package:meta/meta.dart';

part "media.chopper.dart";

@ChopperApi(baseUrl: "/$apiBase/media/$apiVersion")
abstract class MediaService extends ChopperService {
  static MediaService create([ChopperClient client]) =>
      _$MediaService(client);

  @Get(path: 'download/{serverName}/{mediaId}')
  Future<Response> download(
      @Path('serverName') String serverName, @Path('mediaId') String mediaId);

  @Get(path: 'thumbnail/{serverName}/{mediaId}')
  Future<Response> thumbnail(
    @Path('serverName') String serverName,
    @Path('mediaId') String mediaId,
    @Query('width') int width,
    @Query('height') int height,
    @Query('method') String method
  );
}

==> 0.15.1.tar.gz: lib/src/api/media.dart <==
// Copyright (C) 2019  Wilko Manger
//
// This file is part of matrix-dart-sdk.
//
// matrix-dart-sdk is free software: you can redistribute it and/or modify
// it under the terms of the GNU Affero General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// matrix-dart-sdk is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Affero General Public License for more details.
//
// You should have received a copy of the GNU Affero General Public License
// along with matrix-dart-sdk.  If not, see <https://www.gnu.org/licenses/>.
import 'dart:async';
import 'package:chopper/chopper.dart';
import 'package:matrix_sdk/src/api/api.dart';
import 'package:meta/meta.dart';

part 'media.chopper.dart';

@ChopperApi(baseUrl: '/$apiBase/media/$apiVersion')
abstract class MediaService extends ChopperService {
  static MediaService create([ChopperClient client]) =>
      _$MediaService(client);

  @Get(path: 'download/{serverName}/{mediaId}')
  Future<Response> download(
      @Path('serverName') String serverName, @Path('mediaId') String mediaId);

  @Get(path: 'thumbnail/{serverName}/{mediaId}')
  Future<Response> thumbnail(
    @Path('serverName') String serverName,
    @Path('mediaId') String mediaId,
    @Query('width') int width,
    @Query('height') int height,
    @Query('method') String method
  );
}
